# GMFlowNet

## Original code

[https://github.com/xiaofeng94/GMFlowNet](https://github.com/xiaofeng94/GMFlowNet)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{xu2022gmflow,
  title={Global Matching with Overlapping Attention for Optical Flow Estimation},
  author={Zhao, Shiyu and Zhao, Long and Zhang, Zhixing and Zhou, Enyu and Metaxas, Dimitris},
  booktitle={Proceedings of the IEEE/CVF Conference on Computer Vision and Pattern Recognition},
  year={2022}
}
```